// Copyright (C) 2007 Juan Manuel Borges Caño

// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.

// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.

// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

#include <config.h>
#include <stdlib.h>
#include <glib.h>
#include <gconf/gconf-client.h>
#include <gtk-tw.h>
#include <glib/gi18n.h>

gint
main(gint argc, gchar *argv[])
{
	gchar *dictionary = NULL, *text = NULL;
	bindtextdomain(PACKAGE, LOCALEDIR);
	bind_textdomain_codeset(PACKAGE, "UTF-8");
	textdomain(PACKAGE);
	gtk_init(&argc, &argv);
	gconf_init(argc, argv, NULL);
	switch(argc)
	{
		case 2:
			text = argv[1];
		break;
		case 3:
			dictionary = argv[1];
			text = argv[2];
		break;
		default:
		break;
	}
	gtk_tw_new(dictionary, text);
	gtk_main();
	return EXIT_SUCCESS;
}
